DecoderInstruction class abstract

QPACK decoder stream instructions per RFC 9204 Section 4.3.2.

These instructions are sent on the decoder stream (0x03) to acknowledge header blocks and update the encoder's insert count.

Implementers

Constructors

DecoderInstruction()
const
DecoderInstruction.parse(Uint8List bytes)
Parse a decoder instruction from bytes.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Encode this instruction into a byte sequence.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited