Duplicate class

RFC 9204 Section 4.3.4 — Duplicate.

Duplicates an existing entry in the dynamic table.

Wire format:

| 0 | 0 | 0 |    Index (5+)     |
Inheritance

Constructors

Duplicate({required int index})
Creates a duplicate instruction for the dynamic table entry at index.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
The relative index of the existing entry to duplicate.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Serialize this instruction to bytes.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited