EncoderInstruction class abstract
Abstract base class for QPACK encoder stream instructions per RFC 9204 Section 4.3.
These instructions are sent on the encoder stream (0x02) to update the dynamic table.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → Uint8List - Serialize this instruction to bytes.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
Uint8List bytes) → EncoderInstruction -
Parse a single encoder instruction from
bytes.