GoawayCapsule class

A GOAWAY capsule (type 0x1d).

Inheritance

Constructors

GoawayCapsule(Uint8List data)

Properties

data Uint8List
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Serializes this capsule into its on-the-wire representation.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited