Http3DataFrame class

HTTP/3 DATA frame payload.

RFC 9114 Section 7.2.1: the payload of a DATA frame consists of a sequence of octets. The DATA frame (type=0x00) carries content of a message.

Constructors

Http3DataFrame({required List<int> data})

Properties

data List<int>
The raw data octets carried by this frame.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFrame() Http3Frame
Build a complete Http3Frame of type DATA.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

empty() Http3DataFrame
Empty data frame.
fromPayload(List<int> payload) Http3DataFrame
Parse from an Http3Frame payload.