body property
The optional request body.
When non-null and non-empty, Http3Connection.sendRequest writes the body as one or more HTTP/3 DATA frames.
Implementation
final Uint8List? body;
The optional request body.
When non-null and non-empty, Http3Connection.sendRequest writes the body as one or more HTTP/3 DATA frames.
final Uint8List? body;