InsertCountIncrement class

Insert Count Increment instruction (T = 00, 6-bit prefix).

Sent to inform the encoder that the decoder has received increment dynamic table insertions.

Inheritance

Constructors

InsertCountIncrement({required int increment})
Creates an insert count increment instruction for increment.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
increment int
Number of dynamic table insertions the decoder has received.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Encode this instruction into a byte sequence.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited