InsertWithNameReference constructor

InsertWithNameReference({
  1. required bool isStatic,
  2. required int nameIndex,
  3. required String value,
})

Creates an instruction that inserts a new dynamic table entry with the field name from an existing entry and the literal value.

Implementation

InsertWithNameReference({
  required this.isStatic,
  required this.nameIndex,
  required this.value,
});