isStatic property
true when the name reference points to the static table (T=1);
false when it points to the dynamic table (T=0).
Implementation
final bool isStatic;
true when the name reference points to the static table (T=1);
false when it points to the dynamic table (T=0).
final bool isStatic;