InsertWithoutNameReference class
RFC 9204 Section 4.3.3 — Insert with Literal Name.
Adds a dynamic table entry where both the field name and field value are transmitted as string literals.
Wire format:
| 0 | 1 | H | Name Length (5+) |
| Name String (Length bytes) |
| H | Value Length (7+) |
| Value String (Length bytes) |
- Inheritance
-
- Object
- EncoderInstruction
- InsertWithoutNameReference
Constructors
- InsertWithoutNameReference({required String name, required String value})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → Uint8List -
Serialize this instruction to bytes.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited