RegisterUnidirectionalStreamCapsule class

A REGISTER_UNIDIRECTIONAL_STREAM capsule (type 0x42).

Inheritance

Constructors

RegisterUnidirectionalStreamCapsule(Uint8List data)
Creates a REGISTER_UNIDIRECTIONAL_STREAM capsule carrying data.

Properties

data Uint8List
Opaque capsule payload bytes.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int
Capsule type identifier as a VarInt (e.g., 0x00 for DATAGRAM).
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Serializes this capsule into its on-the-wire representation.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited