SectionAcknowledgment class

Section Acknowledgment instruction (T = 1, 7-bit prefix).

Sent to acknowledge that a header block for streamId has been processed.

Inheritance

Constructors

SectionAcknowledgment({required int streamId})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamId int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Encode this instruction into a byte sequence.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited