SetDynamicTableCapacity class

RFC 9204 Section 4.3.1 — Set Dynamic Table Capacity.

Changes the capacity of the dynamic table.

Wire format:

| 0 | 0 | 1 |   Capacity (5+)   |
Inheritance

Constructors

SetDynamicTableCapacity({required int capacity})
Creates an instruction that sets the dynamic table capacity to capacity.

Properties

capacity int
The new dynamic table capacity.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Serialize this instruction to bytes.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited