StreamCancellation class
Stream Cancellation instruction (T = 01, 6-bit prefix).
Sent to indicate that streamId was cancelled before its header block was fully processed.
- Inheritance
-
- Object
- DecoderInstruction
- StreamCancellation
Constructors
- StreamCancellation({required int streamId})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → Uint8List -
Encode this instruction into a byte sequence.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited