StreamType enum
Unidirectional stream type identifiers per RFC 9114 Section 6.2.
Each unidirectional stream begins with a single varint-encoded stream type.
Values
- control → const StreamType
-
Control stream (RFC 9114 Section 6.2.1).
const StreamType(0x00) - push → const StreamType
-
Push stream (RFC 9114 Section 6.2.2).
const StreamType(0x01) - qpackEncoder → const StreamType
-
QPACK encoder stream (RFC 9204 Section 4.2).
const StreamType(0x02) - qpackDecoder → const StreamType
-
QPACK decoder stream (RFC 9204 Section 4.2).
const StreamType(0x03)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → StreamType? - Looks up a stream type by its wire value.
Constants
-
values
→ const List<
StreamType> - A constant List of the values in this enum, in order of their declaration.