fromValue static method
Looks up a stream type by its wire value.
Implementation
static StreamType? fromValue(int value) {
for (final type in values) {
if (type.value == value) return type;
}
return null;
}
Looks up a stream type by its wire value.
static StreamType? fromValue(int value) {
for (final type in values) {
if (type.value == value) return type;
}
return null;
}