UnknownCapsule class

An unknown capsule type encountered on the wire.

Per draft-ietf-webtrans-http3, unknown capsule types MUST be ignored.

Inheritance

Constructors

UnknownCapsule(int type, Uint8List data)
Creates an unknown capsule with the given type and data.

Properties

data Uint8List
Opaque capsule payload bytes.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int
Capsule type identifier as a VarInt (e.g., 0x00 for DATAGRAM).
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Serializes this capsule into its on-the-wire representation.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited