WtMaxDataCapsule class
WT_MAX_DATA capsule (draft-ietf-webtrans-http3 5.6.3).
Carries a VarInt count of maximum bytes allowed for a session.
Constructors
- WtMaxDataCapsule(Uint8List data)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → Uint8List -
Serializes this capsule into its on-the-wire representation.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited