WtMaxStreamDataCapsule class
WT_MAX_STREAM_DATA capsule (draft-ietf-webtrans-http3 5.6.4).
Carries a VarInt count of maximum bytes allowed on a stream.
Constructors
- WtMaxStreamDataCapsule(Uint8List data)
-
Creates a WT_MAX_STREAM_DATA capsule carrying
data.
Properties
- data → Uint8List
-
Opaque capsule payload bytes.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxStreamData → int
-
Maximum stream data value encoded in the capsule payload.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → int
-
Capsule type identifier as a VarInt (e.g., 0x00 for DATAGRAM).
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → Uint8List -
Serializes this capsule into its on-the-wire representation.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited