WebTransportConnectRequest class

Extended CONNECT request for WebTransport.

Method: CONNECT, Protocol: :protocol = webtransport, plus :scheme, :authority, and :path pseudo-headers.

Constructors

WebTransportConnectRequest({required String authority, required String path, String? origin})
Creates a WebTransport CONNECT request for authority and path.

Properties

authority String
The :authority pseudo-header (e.g., "example.com").
final
hashCode int
The hash code for this object.
no setterinherited
origin String?
Optional Origin header value, if provided by the client.
final
path String
The :path pseudo-header (e.g., "/session").
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited