CertificateMessage class

TLS 1.3 Certificate structure per RFC 8446 Section 4.4.2.

struct {
    opaque request_context<0..2^8-1>;
    CertificateEntry certificate_list<0..2^24-1>;
} Certificate;

Constructors

CertificateMessage({List<int> requestContext = const [], required List<CertificateEntry> entries})

Properties

entries List<CertificateEntry>
List of certificate entries.
final
hashCode int
The hash code for this object.
no setterinherited
requestContext List<int>
Empty in server cert, may have data in client cert.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Serialize per RFC 8446 4.4.2: uint8 request_context_length uint8[] request_context uint24 certificates_length CertificateEntry[]
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(Uint8List bytes) CertificateMessage
Parse from bytes.