incomingPort property
dynamic
get
incomingPort
The port that the supervisor should use to send messages to this isolate.
Implementation
dynamic get incomingPort => _controller;
The port that the supervisor should use to send messages to this isolate.
dynamic get incomingPort => _controller;