HeaderProtection class

QUIC header protection per RFC 9001 Section 5.4.

Constructors

HeaderProtection({required List<int> hpKey, required bool isChaCha20})
Creates header protection for the given header-protection key.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(Uint8List header, Uint8List payload) Uint8List
Apply header protection to a packet. header is the unprotected header bytes. payload is the encrypted payload (needed for sample extraction). Returns the protected header bytes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(Uint8List header, Uint8List payload) Uint8List
Remove header protection from a packet. header is the protected header bytes. payload is the encrypted payload. Returns the unprotected header bytes.
removeShortHeader(Uint8List header, Uint8List payload, int pnLen) Uint8List
Remove header protection from a short header using a specific pnLen.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited