Http3FrameType enum

HTTP/3 frame types per RFC 9114 Section 7.2.

Inheritance
Available extensions

Values

data → const Http3FrameType
const Http3FrameType(0x00)
headers → const Http3FrameType
const Http3FrameType(0x01)
cancelPush → const Http3FrameType
const Http3FrameType(0x03)
settings → const Http3FrameType
const Http3FrameType(0x04)
pushPromise → const Http3FrameType
const Http3FrameType(0x05)
goaway → const Http3FrameType
const Http3FrameType(0x07)
origin → const Http3FrameType
const Http3FrameType(0x0c)
maxPushId → const Http3FrameType
const Http3FrameType(0x0d)
reserved → const Http3FrameType
const Http3FrameType(0x21)
priorityUpdate → const Http3FrameType
const Http3FrameType(0xF0700)
priorityUpdatePush → const Http3FrameType
const Http3FrameType(0xF0701)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) Http3FrameType?
Looks up a frame type by its wire value.

Constants

values → const List<Http3FrameType>
A constant List of the values in this enum, in order of their declaration.