Http3PushPromiseFrame class

HTTP/3 PUSH_PROMISE frame payload.

RFC 9114 Section 7.2.5: the payload consists of a VarInt-encoded Push ID followed by an encoded field section (QPACK-encoded request headers).

Constructors

Http3PushPromiseFrame({required int pushId, required List<int> encodedFieldSection})

Properties

encodedFieldSection List<int>
The encoded field section, i.e., a QPACK-encoded header block.
final
hashCode int
The hash code for this object.
no setteroverride
pushId int
The Push ID that the server is reserving for this server push.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Alias for serializePayload.
serializePayload() Uint8List
Serialize payload: VarInt(pushId) + encodedFieldSection
toFrame() Http3Frame
Build a complete frame.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

parse(Uint8List bytes) Http3PushPromiseFrame
Alias for parsePayload.
parsePayload(Uint8List payload) Http3PushPromiseFrame
Parse payload.