Http3SettingsFrame class

HTTP/3 SETTINGS frame payload.

RFC 9114 Section 7.2.4: the payload is a sequence of VarInt(identifier), VarInt(value) pairs.

Constructors

Http3SettingsFrame({Map<int, int> settings = const {}})
Creates a SETTINGS frame.
Http3SettingsFrame.from({int? maxFieldSectionSize, int? maxTableCapacity, int? blockedStreams, int? enableConnectProtocol, int? h3Datagram, int? wtEnabled, int? wtInitialMaxData, int? wtInitialMaxStreamsUni, int? wtInitialMaxStreamsBidi})
Convenience: create from known settings.
factory

Properties

blockedStreams int
SETTINGS_QPACK_BLOCKED_STREAMS, or 0 if not present.
no setter
hashCode int
The hash code for this object.
no setteroverride
maxFieldSectionSize int
SETTINGS_MAX_FIELD_SECTION_SIZE, or 0 if not present.
no setter
maxTableCapacity int
SETTINGS_QPACK_MAX_TABLE_CAPACITY, or 0 if not present.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings Map<int, int>
Raw map of setting identifier values to setting values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serializePayload() Uint8List
Serialize settings as a sequence of VarInt(id), VarInt(value) pairs.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

parsePayload(Uint8List payload) Http3SettingsFrame
Parse settings payload.