MultiaddrComponent class

A single protocol/value pair within a Multiaddr.

Each component describes one layer of the network stack, such as ip4, udp, or quic-v1. Some protocols (e.g., quic-v1) have no value and are represented with a null value.

See also:

  • Multiaddr — the aggregate address composed of these components.

Constructors

MultiaddrComponent({required String protocol, String? value})
Creates a MultiaddrComponent for protocol with an optional value.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
protocol String
Protocol name (e.g., ip4, udp, quic-v1).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
Protocol value, or null if the protocol has no value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override