OcspException class

Exception thrown when an OCSP fetch or parse operation fails.

Implemented types

Constructors

OcspException(String message)
Creates an OcspException with message.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of the failure.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited