nextUpdate property

DateTime? nextUpdate
final

The time at which the status assertion expires (nextUpdate).

null when the responder did not include the field.

Implementation

final DateTime? nextUpdate;