PacingCalculator class

QUIC packet pacing calculator.

Computes the pacing rate and interval based on smoothed RTT and the current congestion window, as described in RFC 9002 Section 7.7.

Constructors

PacingCalculator({int smoothedRttUs = 333000, int congestionWindow = 2400, int packetSize = 1200})

Properties

hashCode int
The hash code for this object.
no setterinherited
pacingIntervalUs int
Time to wait between packets in microseconds.
no setter
pacingRate double
Pacing rate in bytes per microsecond.
no setter
packetSize int
Packet size in bytes (default 1200).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldPace bool
Whether pacing is needed (RFC: pace when cwnd > 2*packet_size).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
Reset to default values.
toString() String
A string representation of this object.
inherited
updateCongestionWindow(int cwnd) → void
Update congestion window.
updateRtt(int smoothedRttUs) → void
Update RTT.

Operators

operator ==(Object other) bool
The equality operator.
inherited