PacketSender class

Builds and tracks outgoing QUIC packets.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

buildPacket({required List<Frame> frames, required PacketNumberSpace space, required List<int> dcid, List<int>? scid, required int packetNumber, bool greaseQuicBit = false, bool keyPhase = false}) Future<Uint8List>
Build a packet for a given space.
shouldSendPacket(PacketNumberSpace space, List<Frame> frames) bool
Check if a packet should be sent for a space.
trackSentPacket(SentPacketTracker tracker, SentPacketInfo info) → void
Track a sent packet.

Constants

maxUdpPayloadSize → const int