toString method
Returns a lowercase hex string representation of the raw bytes.
Each byte is rendered as two hexadecimal digits (e.g. 0a1f2c).
For Base58 or Base36 representations use toBase58 or toBase36.
Implementation
@override
String toString() {
return bytes.map((b) => b.toRadixString(16).padLeft(2, '0')).join();
}