StreamScheduler class abstract

Abstract interface for selecting the next QUIC stream to process.

Different applications have different scheduling needs: a web server may prioritize certain streams; a libp2p node may want fair bandwidth sharing; a media client may prioritize video over metadata. Implementing this interface allows custom schedulers to be injected into StreamManager.

Implementers

Constructors

StreamScheduler()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
selectNextStream(List<int> activeStreamIds) int
Select the next stream ID to process from activeStreamIds.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited