GoawayCapsule class

A WebTransport GOAWAY capsule (draft-ietf-webtrans-http3).

Signals that the sender will not initiate any new WebTransport sessions on the current connection, and optionally specifies the last stream ID that will be accepted.

Constructors

GoawayCapsule({int? streamId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamId int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Serialize to bytes: VarInt(type) + optional VarInt(streamId).
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

parse(Uint8List bytes) GoawayCapsule
Parse from bytes, skipping the leading type varint.