StreamCapsule class

A WebTransport capsule that registers a stream for a session.

Constructors

StreamCapsule({required int streamId, required CapsuleType type})
Creates a stream-registration capsule.

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamId int
QUIC stream ID being registered.
final
type CapsuleType
Capsule type (register bidirectional or unidirectional stream).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Serialize to bytes: VarInt(type) + VarInt(streamId)
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

parse(Uint8List bytes) StreamCapsule
Parse from bytes.