CloseWebTransportSessionCapsule class

A CLOSE_WEBTRANSPORT_SESSION capsule (type 0x2843).

Inheritance

Constructors

CloseWebTransportSessionCapsule({Uint8List? data, int errorCode = 0, String? errorMessage})

Properties

data Uint8List
finalinherited
errorCode int
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
Serializes this capsule into its on-the-wire representation.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited