getPushStreamId method

int? getPushStreamId(
  1. int pushId
)

Returns the QUIC stream ID allocated for the push stream carrying pushId, or null if the server has not yet sent a push response for that push ID.

On the server side this is populated by sendPushResponse.

Implementation

int? getPushStreamId(int pushId) => _pushStreamIds[pushId];