InsertCountIncrement class
Insert Count Increment instruction (T = 00, 6-bit prefix).
Sent to inform the encoder that the decoder has received increment dynamic table insertions.
- Inheritance
-
- Object
- DecoderInstruction
- InsertCountIncrement
Constructors
- InsertCountIncrement({required int increment})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → Uint8List -
Encode this instruction into a byte sequence.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited