InsertWithNameReference class
RFC 9204 Section 4.3.2 — Insert with Name Reference.
Adds a dynamic table entry whose field name matches an existing entry in the static or dynamic table. The field value is transmitted as a string literal.
Wire format:
| 1 | T | Name Index (6+) |
| H | Value Length (7+) |
| Value String (Length bytes) |
- Inheritance
-
- Object
- EncoderInstruction
- InsertWithNameReference
Constructors
- InsertWithNameReference({required bool isStatic, required int nameIndex, required String value})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isStatic → bool
-
truewhen the name reference points to the static table (T=1);falsewhen it points to the dynamic table (T=0).final - nameIndex → int
-
The index of the name in the referenced table.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The field value to store in the new dynamic table entry.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → Uint8List -
Serialize this instruction to bytes.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited