WtMaxStreamsCapsule class
WT_MAX_STREAMS capsule (draft-ietf-webtrans-http3 5.6.2).
Carries a VarInt count of maximum streams allowed for a session.
Constructors
- WtMaxStreamsCapsule.bidi(Uint8List data)
-
Creates a bidirectional WT_MAX_STREAMS capsule carrying
data. - WtMaxStreamsCapsule.uni(Uint8List data)
-
Creates a unidirectional WT_MAX_STREAMS capsule carrying
data.
Properties
- bidirectional → bool
-
trueif this limit applies to bidirectional streams.final - data → Uint8List
-
Opaque capsule payload bytes.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxStreams → int
-
Maximum streams value encoded in the capsule payload.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → int
-
Capsule type identifier as a VarInt (e.g., 0x00 for DATAGRAM).
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → Uint8List -
Serializes this capsule into its on-the-wire representation.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited