DCUtRHandler class
Handler for producing and validating DCUtR messages.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
initiateConnect(
List< int> observedAddr) → DCUtRMessage - Initiate a DCUtR handshake as the dialer.
-
isValid(
DCUtRMessage msg) → bool - Validate a received DCUtR message.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
respondSync(
List< int> observedAddr) → DCUtRMessage - Respond to a DCUtR CONNECT with a SYNC.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- typeConnect → const int
- typeSync → const int