WebTransportConnectRequest class

Extended CONNECT request for WebTransport. Method: CONNECT, Protocol: :protocol = webtransport, :scheme, :authority, :path

Constructors

WebTransportConnectRequest({required String authority, required String path, String? origin})

Properties

authority String
final
hashCode int
The hash code for this object.
no setterinherited
origin String?
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited