Http3StreamHandler class
Handles classification of an HTTP/3 stream based on its QUIC stream ID.
Per RFC 9114 4.1:
- Control stream: stream ID 0x00 for client, 0x01 for server
- Push stream: server-initiated unidirectional (type bits = 0x03)
- Request stream: client-initiated bidirectional (type bits = 0x00)
Constructors
- Http3StreamHandler(int streamId, {bool isServer = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isControlStream → bool
-
Is this a control stream?
no setter
- isPushStream → bool
-
Is this a push stream?
no setter
- isRequestStream → bool
-
Is this a request stream?
no setter
- isServer → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamId → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
typeFromStreamId(
int streamId, bool isServer) → Http3StreamType - Determine the HTTP/3 stream type from the QUIC stream ID.