InitialSecrets class

QUIC Initial Secret derivation per RFC 9001 Section 5.2.

Constructors

InitialSecrets()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

initialSalt List<int>
QUIC v1 fixed initial salt (RFC 9001 Section 5.2).
final

Static Methods

derive(List<int> destinationConnectionId, {required CryptoBackend backend}) Future<({SecretKey clientSecret, SecretKey serverSecret})>
Derive client and server initial secrets from the destination connection ID.