OcspVerdict class
The verdict returned by OcspFetcher after querying an OCSP responder.
Contains the parsed status plus the thisUpdate / nextUpdate freshness
timestamps from the SingleResponse.
Constructors
- OcspVerdict({required OcspCertStatus status, DateTime? thisUpdate, DateTime? nextUpdate})
-
Creates an OCSP verdict.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextUpdate → DateTime?
-
The time at which the status assertion expires (
nextUpdate).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → OcspCertStatus
-
The revocation status reported by the responder.
final
- thisUpdate → DateTime?
-
The time at which the status was asserted to be correct (
thisUpdate).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited