nextUpdate property
The time at which the status assertion expires (nextUpdate).
null when the responder did not include the field.
Implementation
final DateTime? nextUpdate;
The time at which the status assertion expires (nextUpdate).
null when the responder did not include the field.
final DateTime? nextUpdate;