PacketNumberSpace enum
QUIC packet number spaces per RFC 9000.
QUIC uses three distinct packet number spaces, each with independent packet number sequences. This prevents retransmissions of a packet in one space from being acknowledged by packets in another space.
Values
- initial → const PacketNumberSpace
-
const PacketNumberSpace(0) - handshake → const PacketNumberSpace
-
const PacketNumberSpace(1) - application → const PacketNumberSpace
-
const PacketNumberSpace(2) - zeroRtt → const PacketNumberSpace
-
const PacketNumberSpace(3)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spaceIndex → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PacketNumberSpace> - A constant List of the values in this enum, in order of their declaration.