PacketReceiver class
Processes incoming QUIC packets from raw UDP datagrams.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
processDatagram(
Uint8List datagram) → List< ({List< Frame> frames, PacketHeader header, PacketNumberSpace? space})> - Process a raw UDP datagram, splitting coalesced packets if needed.
-
processPacket(
Uint8List packet) → ({List< Frame> frames, PacketHeader header, PacketNumberSpace? space})? - Process a single QUIC packet. Returns null if the packet is a Retry or Version Negotiation (special handling needed).
-
spaceFromHeader(
PacketHeader header) → PacketNumberSpace? - Determine the packet number space from a header.
Constants
- maxFramesPerPacket → const int