StreamFrame class
A STREAM frame (RFC 9000 Section 19.8).
Constructors
Properties
-
data
→ List<
int> -
final
- fin → bool
-
final
- frameType → int
-
no setteroverride
- hasExplicitLength → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAckEliciting → bool
-
Whether this frame is ack-eliciting per RFC 9000 Table 3.
Default is
true; override for non-ack-eliciting frames.no setterinherited - isInFlight → bool
-
Whether this frame counts toward bytes in flight per RFC 9000 Table 3.
Default matches isAckEliciting; override for frames that are not
ack-eliciting but still should not count (e.g., CONNECTION_CLOSE).
no setterinherited
- offset → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamId → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → Uint8List -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited