UdpSocket class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
incoming
→ Stream<
({InternetAddress address, Uint8List data, int port})> -
no setter
- localAddress → InternetAddress
-
no setter
- localPort → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
Uint8List data, InternetAddress address, int port) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
bind(
InternetAddress address, int port) → Future< UdpSocket>