WebTransportStreamId class
Discriminator and encoder/decoder for WebTransport stream IDs.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
encode(
{required int type, required int sequence}) → int -
Encodes a
typeconstant andsequencenumber into a stream ID. -
getType(
int streamId) → WebTransportStreamType -
Returns the directionality of the given
streamId. -
isClientInitiated(
int streamId) → bool -
Returns
trueifstreamIdwas opened by the client. -
isServerInitiated(
int streamId) → bool -
Returns
trueifstreamIdwas opened by the server. -
sequence(
int streamId) → int -
Extracts the sequence number from
streamId.
Constants
- typeClientBidi → const int
- Two-bit type constant for a client-initiated bidirectional stream.
- typeClientUni → const int
- Two-bit type constant for a client-initiated unidirectional stream.
- typeServerBidi → const int
- Two-bit type constant for a server-initiated bidirectional stream.
- typeServerUni → const int
- Two-bit type constant for a server-initiated unidirectional stream.